@@ -3,7 +3,7 @@ package SockJS;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use overload '&{}' => sub { shift->to_app(@_) }, fallback => 1;
 
@@ -137,7 +137,7 @@ sub _dispatch_transport {
           ->($self, id => $id, connection => $conn, type => $transport->name);
 
         my $close_timer;
-        $conn->on(connect => sub { $self->{handler}->($session); });
+        $conn->on(connect => sub { $self->{handler}->($session, $env); });
         $conn->on(data => sub { shift; $session->fire_event(data => @_) });
         $conn->on(
             close => sub {
